@@ -321,7 +321,6 @@ _custom_ioa_endpoints = [
         "enum": [
           "created_by",
           "created_on",
-          "description",
           "enabled",
           "modified_by",
           "modified_on",
@@ -329,7 +328,7 @@ _custom_ioa_endpoints = [
         ],
         "type": "string",
         "description": "Possible order by fields: {created_by, created_on, modified_by, "
-        "modified_on, enabled, name, description}",
+        "modified_on, enabled, name}",
         "name": "sort",
         "in": "query"
       },
@@ -373,7 +372,6 @@ _custom_ioa_endpoints = [
         "enum": [
           "created_by",
           "created_on",
-          "description",
           "enabled",
           "modified_by",
           "modified_on",
@@ -381,7 +379,7 @@ _custom_ioa_endpoints = [
         ],
         "type": "string",
         "description": "Possible order by fields: {created_by, created_on, modified_by, "
-        "modified_on, enabled, name, description}",
+        "modified_on, enabled, name}",
         "name": "sort",
         "in": "query"
       },
