@@ -178,19 +178,27 @@ _firewall_management_endpoints = [
     ]
   ],
   [
-    "update-policy-container",
+    "update-policy-container-v1",
     "PUT",
     "/fwmgr/entities/policies/v1",
-    "Update an identified policy container",
+    "Update an identified policy container. WARNING: This endpoint is deprecated in "
+    "favor of v2, using this endpoint could disable your local logging setting.",
     "firewall_management",
     [
       {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
+        "name": "body",
+        "in": "body",
         "required": True
-      },
+      }
+    ]
+  ],
+  [
+    "update-policy-container",
+    "PUT",
+    "/fwmgr/entities/policies/v2",
+    "Update an identified policy container, including local logging functionality.",
+    "firewall_management",
+    [
       {
         "name": "body",
         "in": "body",
@@ -202,7 +210,8 @@ _firewall_management_endpoints = [
     "get-rule-groups",
     "GET",
     "/fwmgr/entities/rule-groups/v1",
-    "Get rule group entities by ID. These groups do not contain their rule entites, just the rule IDs in precedence order.",
+    "Get rule group entities by ID. These groups do not contain their rule entites, "
+    "just the rule IDs in precedence order.",
     "firewall_management",
     [
       {
@@ -225,13 +234,6 @@ _firewall_management_endpoints = [
     "Create new rule group on a platform for a customer with a name and description, and return the ID",
     "firewall_management",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
-        "required": True
-      },
       {
         "type": "string",
         "description": "A rule group ID from which to copy rules. "
@@ -266,13 +268,6 @@ _firewall_management_endpoints = [
     "Update name, description, or enabled status of a rule group, or create, edit, delete, or reorder rules",
     "firewall_management",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
-        "required": True
-      },
       {
         "type": "string",
         "description": "Audit log comment for this action",
@@ -293,13 +288,6 @@ _firewall_management_endpoints = [
     "Delete rule group entities by ID",
     "firewall_management",
     [
-      {
-        "type": "string",
-        "description": "The user id",
-        "name": "X-CS-USERNAME",
-        "in": "header",
-        "required": True
-      },
       {
         "type": "array",
         "items": {
@@ -319,6 +307,61 @@ _firewall_management_endpoints = [
       }
     ]
   ],
+  [
+    "create-rule-group-validation",
+    "POST",
+    "/fwmgr/entities/rule-groups/validation/v1",
+    "Validates the request of creating a new rule group on a platform for a customer with a name and description",
+    "firewall_management",
+    [
+      {
+        "type": "string",
+        "description": "A rule group ID from which to copy rules. "
+        "If this is provided then the 'rules' property of the body is ignored.",
+        "name": "clone_id",
+        "in": "query"
+      },
+      {
+        "type": "string",
+        "description": "If this flag is set to true then the rules will be cloned from the "
+        "clone_id from the CrowdStrike Firewall Rule Groups Library.",
+        "name": "library",
+        "in": "query"
+      },
+      {
+        "type": "string",
+        "description": "Audit log comment for this action",
+        "name": "comment",
+        "in": "query"
+      },
+      {
+        "name": "body",
+        "in": "body",
+        "required": True
+      }
+    ]
+  ],
+  [
+    "update-rule-group-validation",
+    "PATCH",
+    "/fwmgr/entities/rule-groups/validation/v1",
+    "Validates the request of updating name, description, or enabled status of a rule group, "
+    "or create, edit, delete, or reorder rules",
+    "firewall_management",
+    [
+      {
+        "type": "string",
+        "description": "Audit log comment for this action",
+        "name": "comment",
+        "in": "query"
+      },
+      {
+        "name": "body",
+        "in": "body",
+        "required": True
+      }
+    ]
+  ],
   [
     "get-rules",
     "GET",
@@ -339,6 +382,20 @@ _firewall_management_endpoints = [
       }
     ]
   ],
+  [
+    "validate-filepath-pattern",
+    "POST",
+    "/fwmgr/entities/rules/validate-filepath/v1",
+    "Validates that the test pattern matches the executable filepath glob pattern.",
+    "firewall_management",
+    [
+      {
+        "name": "body",
+        "in": "body",
+        "required": True
+      }
+    ]
+  ],
   [
     "query-events",
     "GET",
